@@ -104,7 +104,7 @@ def get_tickets_with_properties_history(hapikey, app_private_token, properties,
             results_part_1 = response_dict["results"]
         except Exception as e:
             attempts += 1
-            prefect.context.logger.info(f"Error {e}")
+            prefect.get_run_logger().info(f"Error {e}")
             if attempts > 2:
                 raise e
             sleep(10)
@@ -123,7 +123,7 @@ def get_tickets_with_properties_history(hapikey, app_private_token, properties,
             results_part_2 = response_dict["results"]
         except Exception as e:
             attempts += 1
-            prefect.context.logger.info(f"Error {e}")
+            prefect.get_run_logger().info(f"Error {e}")
             if attempts > 2:
                 raise e
             sleep(10)
