@@ -3,20 +3,27 @@ import adal
 from .adminGroupsService import adminGroups
 from .activityLogs import activityLogs
 from .dataset_service import DatasetService
+from .user_service import UserService
 
 
 class PowerBIClient:
-    default_resource_url = 'https://analysis.windows.net/powerbi/api'
-    default_api_url = 'https://api.powerbi.com'
-    default_authority_url = 'https://login.windows.net/common'
+    default_resource_url = "https://analysis.windows.net/powerbi/api"
+    default_api_url = "https://api.powerbi.com"
+    default_authority_url = "https://login.windows.net/common"
 
-    api_version_snippet = 'v1.0'
-    api_myorg_snippet = 'myorg'
-    api_admin_snippet = 'admin'
+    api_version_snippet = "v1.0"
+    api_myorg_snippet = "myorg"
+    api_admin_snippet = "admin"
 
     @staticmethod
-    def get_client_with_username_password(client_id, username, password, authority_url=None, resource_url=None,
-                                          api_url=None):
+    def get_client_with_username_password(
+        client_id,
+        username,
+        password,
+        authority_url=None,
+        resource_url=None,
+        api_url=None,
+    ):
         """
         Constructs a client with the option of using common defaults.
 
@@ -37,15 +44,17 @@ class PowerBIClient:
         if api_url is None:
             api_url = PowerBIClient.default_api_url
 
-        context = adal.AuthenticationContext(authority=authority_url,
-                                             validate_authority=True,
-                                             api_version=None)
+        context = adal.AuthenticationContext(
+            authority=authority_url, validate_authority=True, api_version=None
+        )
 
         # get your authentication token
-        token = context.acquire_token_with_username_password(resource=resource_url,
-                                                             client_id=client_id,
-                                                             username=username,
-                                                             password=password)
+        token = context.acquire_token_with_username_password(
+            resource=resource_url,
+            client_id=client_id,
+            username=username,
+            password=password,
+        )
 
         return PowerBIClient(api_url, token)
 
@@ -56,6 +65,7 @@ class PowerBIClient:
         self.activityLogs = activityLogs(self)
         self.adminGroups = adminGroups(self)
         self.datasets = DatasetService(self)
+        self.users = UserService(self)
         # self.reports = Reports(self)
         # self.imports = Imports(self)
         # self.groups = Groups(self)
@@ -65,7 +75,7 @@ class PowerBIClient:
     def auth_header(self):
         if self.__auth_header is None:
             self.__auth_header = {
-                'Authorization': f'Bearer {self.token["accessToken"]}'
+                "Authorization": f'Bearer {self.token["accessToken"]}'
             }
 
         return self.__auth_header
